function varargout=slice(self,u,P,varargin)
% FUNCTION slice
%   Plots scalar data values on the intersection of the plane defined by
%         P(1)*x+P(2)*y+P(3)*z+P(4)=0
%   and the siMesh object.
%
% USAGE
%   Th.slice(u,P) or slice(Th,u,P) where 
%     Th is a siMesh object,
%     u  is the data values on Th vertices, Th.nq-by-1 array,
%     P  is a vector which contains the coefficients of the plane.
%
%   Th.slice(u,P,key,value,...) allows additional key/value pairs to be 
%     used when displaying the siMesh object. The key strings could be
%
%     'labels' to specify the labels of the elementary meshes. 
%              Default [] i.e all.
%
% SAMPLES
%   Th=fc_simesh.HyperCube(3,10);
%   U=Th.eval(@(x,y,z) cos(2*x-y+z).*sin(x+y-3*z));
%   P=fc_tools.graphics.PlaneCoefs(0.5*[1 1 1],[1 -1 1]);
%   figure(1)
%   Th.slice(U,P)
%   hold on
%   Th.plot('d',1,'color','k')
%
%    <COPYRIGHT>
  assert(self.d==3 && self.dim==3);
  p = inputParser; 
  p.KeepUnmatched=true; 
  p.addParamValue('labels',[]); % select labels to draw
  p.parse(varargin{:});
  R=p.Results;
  varargin=fc_tools.utils.deleteCellOptions(varargin,p.Parameters);
  
  if isempty(R.labels), idxlab=self.find(3);else idxlab=self.find(3,R.labels);end
  if isempty(idxlab), return;end
  PrevHold=fc_tools.graphics.SetHoldOn(true);
  if ~PrevHold, clf;hold on;end
  for ilab=[idxlab]
    self.sTh{ilab}.slice(u,P,varargin{:});
  end
  fc_tools.graphics.RestoreHold(PrevHold)
end
